@@ -1,7 +1,7 @@
 /*
-    Copyright (c) 2000, 2003	    Dmitry K. Butskoj
-				    <buc@citadel.stu.neva.ru>
-    License:  LGPL		
+    Copyright (c)  2000, 2003		Dmitry Butskoy
+					<buc@citadel.stu.neva.ru>
+    License:  LGPL v2.1 or any later
 
     See COPYING.LIB for the status of this software.
 */
@@ -792,9 +792,9 @@ static void box_output (int start, int left, int width, const char *str,
 	if (l > 0) {
 	    memset (buf, ' ', l);
 	    buf[l] = '\0';
-	    fprintf (stderr, buf);
+	    fprintf (stderr, "%s", buf);
 	} else 
-	    fprintf (stderr, spacer);
+	    fprintf (stderr, "%s", spacer);
 
 
 	endp = buf + width;
@@ -833,7 +833,7 @@ static void box_output (int start, int left, int width, const char *str,
 		    
 	    *p = '\0';
 	    fprintf (stderr, "%s", buf);
-	    fprintf (stderr, spacer);
+	    fprintf (stderr, "%s", spacer);
 		
 	    p++;
 	    for (s = buf; *p; *s++ = *p++) ;
